@@ -1,5 +1,5 @@
 //
-// $Id: dnstrace.c,v 1.12 2002/01/17 05:55:50 mavetju Exp $
+// $Id: dnstrace.c,v 1.13 2002/01/18 02:58:03 mavetju Exp $
 //
 
 //
@@ -151,12 +151,12 @@ char *get_resource(int type,struct dnssession *session,char *buffer);
 // Extract information from received packets.
 //
 
-unsigned int getlong(char *s) {
-    return ntohl(s[0]+256*s[1]+256*256*s[2]+256*256*256*s[3]);
+unsigned int getlong(unsigned char *s) {
+    return 256*256*256*s[0]+256*256*s[1]+256*s[2]+s[3];
 }
 
-unsigned short getshort(char *s) {
-    return ntohs(s[0]+256*s[1]);
+unsigned short getshort(unsigned char *s) {
+    return 256*s[0]+s[1];
 }
 
 char *getname(struct dnssession *session,char **thisname) {
@@ -187,7 +187,7 @@ char *getname(struct dnssession *session,char **thisname) {
 	// changing it from now.
 	//
 	if ((p[0]&0xc0)!=0) {
-	    int offset;
+	    unsigned int offset;
 	    char oldp;
 
 	    oldp=p[0];
@@ -682,7 +682,7 @@ int receive_data(struct dnssession *session) {
 	return 1;
 
     if (getshort(buffer)!=session->send_header->identification) {
-	printf("Expected id: %hu, received id: %hu\n",
+	printf("Expected id: %hx, received id: %hx\n",
 	    session->send_header->identification,getshort(buffer));
 	return 4;
     }
@@ -711,7 +711,7 @@ void create_header(struct dnssession *session) {
     // the value received. Looks like it has something to do with
     // one-complement and two-complement, but don't know how to solve it.
     //
-    session->send_header->identification    =random()%(256*256/2);
+    session->send_header->identification    =random() & 0x7F7F;
     session->send_header->nquestions	    =1;
 }
 
